/****************************************
*  Computer Algebra System SINGULAR     *
****************************************/

// syntax table for Singular
//
// - search for an exact match of the argument types
// - otherwise search for the first possibility
//   with converted types of the arguments
// - otherwise report an error
//
// operation: ++ (identifier)  ->  nothing
// operation: -- (identifier)  ->  nothing
// operation: - (int)  ->  int
// operation: - (bigint)  ->  bigint
// operation: - (number)  ->  number
// operation: - (poly)  ->  poly
// operation: - (vector)  ->  vector
// operation: - (matrix)  ->  matrix
// operation: - (intvec)  ->  intvec
// operation: - (intmat)  ->  intmat
// operation: ( (proc)  ->  any_type
// operation: ( (string)  ->  nothing
// operation: attrib (def)  ->  nothing
// operation: bareiss (module)  ->  list
// operation: betti (list)  ->  intmat
// operation: betti (resolution)  ->  intmat
// operation: betti (ideal)  ->  intmat
// operation: betti (module)  ->  intmat
// operation: bigint (bigint)  ->  bigint
// operation: bigint (number)  ->  bigint
// operation: bigint (poly)  ->  bigint
// operation: char (ring)  ->  int
// operation: char (qring)  ->  int
// operation: char_series (ideal)  ->  matrix
// operation: charstr (ring)  ->  string
// operation: charstr (qring)  ->  string
// operation: close (link)  ->  nothing
// operation: ncols (matrix)  ->  int
// operation: ncols (ideal)  ->  int
// operation: ncols (module)  ->  int
// operation: ncols (intmat)  ->  int
// DUMMY // operation: ncols (intvec)  ->  $INVALID$
// operation: cleardenom (poly)  ->  poly
// operation: cleardenom (vector)  ->  vector
// operation: size (number)  ->  int
// operation: size (resolution)  ->  int
// operation: size (string)  ->  int
// operation: size (poly)  ->  int
// operation: size (vector)  ->  int
// operation: size (ideal)  ->  int
// operation: size (module)  ->  int
// operation: size (matrix)  ->  int
// operation: size (intvec)  ->  int
// operation: size (intmat)  ->  int
// operation: size (list)  ->  int
// operation: size (ring)  ->  int
// operation: def (int)  ->  def
// DUMMY // operation: def (any_type)  ->  $INVALID$
// operation: deg (poly)  ->  int
// operation: deg (vector)  ->  int
// operation: deg (matrix)  ->  int
// operation: degree (ideal)  ->  nothing
// operation: degree (module)  ->  nothing
// operation: defined (def)  ->  int
// operation: det (intmat)  ->  int
// operation: det (matrix)  ->  poly
// operation: det (module)  ->  poly
// operation: dim (ideal)  ->  int
// operation: dim (module)  ->  int
// operation: dim (resolution)  ->  int
// operation: dump (link)  ->  nothing
// operation: gen (int)  ->  vector
// operation: execute (string)  ->  nothing
// operation: ERROR (string)  ->  nothing
// operation: factorize (poly)  ->  list
// operation: finduni (ideal)  ->  ideal
// operation: freemodule (int)  ->  module
// operation: facstd (ideal)  ->  list
// operation: getdump (link)  ->  nothing
// operation: highcorner (ideal)  ->  poly
// operation: highcorner (module)  ->  vector
// operation: hilb (ideal)  ->  nothing
// operation: hilb (module)  ->  nothing
// operation: hilb (intvec)  ->  intvec
// operation: homog (ideal)  ->  int
// operation: homog (module)  ->  int
// operation: ideal (ideal)  ->  ideal
// operation: ideal (vector)  ->  ideal
// operation: ideal (matrix)  ->  ideal
// operation: ideal (qring)  ->  ideal
// operation: ideal (ring)  ->  ideal
// operation: ideal (map)  ->  ideal
// operation: impart (number)  ->  number
// operation: indepSet (ideal)  ->  intvec
// operation: int (int)  ->  int
// operation: int (bigint)  ->  int
// operation: int (number)  ->  int
// operation: int (poly)  ->  int
// operation: interred (ideal)  ->  ideal
// operation: interred (module)  ->  module
// operation: intmat (intmat)  ->  intmat
// operation: intvec (intmat)  ->  intvec
// operation: intvec (intvec)  ->  intvec
// operation: rvar (poly)  ->  int
// operation: rvar (string)  ->  int
// operation: rvar (any_type)  ->  int
// operation: jacob (poly)  ->  ideal
// operation: jacob (ideal)  ->  matrix
// operation: jacob (module)  ->  module
// operation: janet (ideal)  ->  ideal
// operation: kbase (ideal)  ->  ideal
// operation: kbase (module)  ->  module
// operation: ludecomp (matrix)  ->  list
// operation: primefactors (bigint)  ->  list
// operation: primefactors (number)  ->  list
// operation: killattrib (identifier)  ->  nothing
// operation: lead (poly)  ->  poly
// operation: lead (ideal)  ->  ideal
// operation: lead (vector)  ->  vector
// operation: lead (module)  ->  module
// operation: leadcoef (poly)  ->  number
// operation: leadcoef (vector)  ->  number
// operation: leadexp (poly)  ->  intvec
// operation: leadexp (vector)  ->  intvec
// operation: leadmonom (poly)  ->  poly
// operation: leadmonom (vector)  ->  vector
// operation: LIB (string)  ->  nothing
// operation: link (link)  ->  link
// operation: list (def)  ->  list
// DUMMY // operation: map (any_type)  ->  $INVALID$
// operation: matrix (matrix)  ->  matrix
// operation: maxideal (int)  ->  ideal
// operation: memory (int)  ->  bigint
// operation: minbase (ideal)  ->  ideal
// operation: minbase (module)  ->  module
// operation: minres (list)  ->  list
// operation: minres (resolution)  ->  resolution
// operation: module (module)  ->  module
// operation: monitor (link)  ->  nothing
// operation: monomial (intvec)  ->  poly
// operation: mult (ideal)  ->  int
// operation: mult (module)  ->  int
// operation: mstd (ideal)  ->  list
// operation: mstd (module)  ->  list
// operation: nameof (any_type)  ->  string
// operation: names (package)  ->  list
// operation: names (ring)  ->  list
// operation: names (qring)  ->  list
// operation: number (number)  ->  number
// operation: number (poly)  ->  number
// operation: number (bigint)  ->  number
// operation: npars (ring)  ->  int
// operation: npars (qring)  ->  int
// operation: nvars (ring)  ->  int
// operation: nvars (qring)  ->  int
// operation: open (link)  ->  nothing
// operation: ord (poly)  ->  int
// operation: ord (vector)  ->  int
// operation: ordstr (ring)  ->  string
// operation: ordstr (qring)  ->  string
// operation: par (int)  ->  number
// operation: pardeg (number)  ->  int
// operation: parstr (int)  ->  string
// operation: parstr (ring)  ->  string
// operation: parstr (qring)  ->  string
// operation: poly (poly)  ->  poly
// operation: poly (bigint)  ->  poly
// operation: preimage (map)  ->  ring
// operation: prime (int)  ->  int
// operation: print (list)  ->  nothing
// operation: print (def)  ->  nothing
// operation: prune (module)  ->  module
// operation: qhweight (ideal)  ->  intvec
// operation: qhweight (module)  ->  intvec
// DUMMY // operation: qring (any_type)  ->  $INVALID$
// operation: read (link)  ->  string
// operation: regularity (list)  ->  int
// operation: repart (number)  ->  number
// operation: reservedName (string)  ->  int
// operation: resolution (list)  ->  resolution
// operation: resolution (resolution)  ->  resolution
// operation: ringlist (ring)  ->  list
// operation: ringlist (qring)  ->  list
// operation: ring (ring)  ->  ring
// operation: ring (list)  ->  ring
// operation: nrows (vector)  ->  int
// operation: nrows (module)  ->  int
// operation: nrows (matrix)  ->  int
// operation: nrows (intmat)  ->  int
// operation: nrows (intvec)  ->  int
// operation: slimgb (ideal)  ->  ideal
// operation: slimgb (module)  ->  module
// operation: sortvec (ideal)  ->  intvec
// operation: sortvec (module)  ->  intvec
// operation: sqrfree (poly)  ->  ideal
// operation: std (ideal)  ->  ideal
// operation: std (module)  ->  module
// operation: string (string)  ->  string
// operation: system (string)  ->  nothing
// operation: syz (ideal)  ->  module
// operation: syz (module)  ->  module
// operation: envelope (ring)  ->  ring
// operation: envelope (qring)  ->  qring
// operation: opposite (ring)  ->  ring
// operation: opposite (qring)  ->  qring
// operation: twostd (ideal)  ->  ideal
// DUMMY // operation: trace (intvec)  ->  $INVALID$
// DUMMY // operation: trace (ideal)  ->  $INVALID$
// operation: trace (intmat)  ->  int
// operation: trace (matrix)  ->  poly
// operation: transpose (intvec)  ->  intmat
// operation: transpose (intmat)  ->  intmat
// operation: transpose (matrix)  ->  matrix
// operation: transpose (module)  ->  module
// operation: typeof (any_type)  ->  string
// operation: univariate (poly)  ->  int
// operation: variables (poly)  ->  ideal
// operation: variables (ideal)  ->  ideal
// operation: variables (matrix)  ->  ideal
// operation: vector (vector)  ->  vector
// operation: vdim (ideal)  ->  int
// operation: vdim (module)  ->  int
// operation: var (int)  ->  poly
// operation: varstr (int)  ->  string
// operation: varstr (ring)  ->  string
// operation: varstr (qring)  ->  string
// operation: weight (ideal)  ->  intvec
// operation: weight (module)  ->  intvec
// operation: load (string)  ->  nothing
// operation: convhull (ideal)  ->  ideal
/*---------------------------------------------*/
// operation: :: (def, def)  ->  any_type
// operation: + (int, int)  ->  int
// operation: + (bigint, bigint)  ->  bigint
// operation: + (number, number)  ->  number
// operation: + (poly, poly)  ->  poly
// operation: + (vector, vector)  ->  vector
// operation: + (ideal, ideal)  ->  ideal
// operation: + (module, module)  ->  module
// operation: + (poly, matrix)  ->  matrix
// operation: + (matrix, poly)  ->  matrix
// operation: + (matrix, matrix)  ->  matrix
// operation: + (string, string)  ->  string
// operation: + (intvec, int)  ->  intvec
// operation: + (int, intvec)  ->  intvec
// operation: + (intmat, int)  ->  intmat
// operation: + (int, intmat)  ->  intmat
// operation: + (intvec, intvec)  ->  intvec
// operation: + (intmat, intmat)  ->  intmat
// operation: + (list, list)  ->  list
// operation: + (ring, ring)  ->  ring
// operation: + (qring, ring)  ->  qring
// operation: + (ring, qring)  ->  qring
// operation: + (qring, qring)  ->  qring
// operation: - (int, int)  ->  int
// operation: - (bigint, bigint)  ->  bigint
// operation: - (number, number)  ->  number
// operation: - (poly, poly)  ->  poly
// operation: - (vector, vector)  ->  vector
// operation: - (matrix, poly)  ->  matrix
// operation: - (matrix, matrix)  ->  matrix
// operation: - (intvec, int)  ->  intvec
// operation: - (intmat, int)  ->  intmat
// operation: - (intvec, intvec)  ->  intvec
// operation: - (intmat, intmat)  ->  intmat
// DUMMY // operation: - (ideal, ideal)  ->  nothing
// DUMMY // operation: - (module, module)  ->  nothing
// operation: * (int, int)  ->  int
// operation: * (bigint, bigint)  ->  bigint
// operation: * (number, number)  ->  number
// operation: * (poly, poly)  ->  poly
// operation: * (poly, vector)  ->  vector
// operation: * (vector, poly)  ->  vector
// operation: * (ideal, poly)  ->  ideal
// operation: * (poly, ideal)  ->  ideal
// operation: * (module, poly)  ->  module
// operation: * (poly, module)  ->  module
// operation: * (ideal, ideal)  ->  ideal
// operation: * (ideal, vector)  ->  module
// operation: * (vector, ideal)  ->  module
// operation: * (ideal, module)  ->  module
// operation: * (module, ideal)  ->  module
// operation: * (matrix, poly)  ->  matrix
// operation: * (poly, matrix)  ->  matrix
// operation: * (matrix, number)  ->  matrix
// operation: * (number, matrix)  ->  matrix
// operation: * (matrix, int)  ->  matrix
// operation: * (int, matrix)  ->  matrix
// operation: * (matrix, matrix)  ->  matrix
// operation: * (matrix, bigint)  ->  matrix
// operation: * (bigint, matrix)  ->  matrix
// operation: * (intvec, int)  ->  intvec
// operation: * (int, intvec)  ->  intvec
// operation: * (intmat, int)  ->  intmat
// operation: * (int, intmat)  ->  intmat
// operation: * (intmat, intvec)  ->  intvec
// operation: * (intmat, intmat)  ->  intmat
// operation: * (intvec, intmat)  ->  intmat
// operation: / (number, number)  ->  number
// operation: / (poly, poly)  ->  poly
// operation: / (vector, poly)  ->  vector
// operation: / (matrix, poly)  ->  matrix
// operation: / (int, int)  ->  int
// operation: / (bigint, bigint)  ->  bigint
// operation: / (intvec, int)  ->  intvec
// operation: / (intmat, int)  ->  intmat
// operation: div (int, int)  ->  int
// operation: div (bigint, bigint)  ->  bigint
// operation: div (intvec, int)  ->  intvec
// operation: div (intmat, int)  ->  intmat
// operation: % (int, int)  ->  int
// operation: % (bigint, bigint)  ->  bigint
// operation: % (intvec, int)  ->  intvec
// operation: % (intmat, int)  ->  intmat
// operation: % (number, number)  ->  number
// operation: mod (int, int)  ->  int
// operation: mod (bigint, bigint)  ->  bigint
// operation: mod (intvec, int)  ->  intvec
// operation: mod (intmat, int)  ->  intmat
// operation: mod (number, number)  ->  number
// operation: ^ (int, int)  ->  int
// operation: ^ (bigint, int)  ->  bigint
// operation: ^ (number, int)  ->  number
// operation: ^ (poly, int)  ->  poly
// operation: ^ (ideal, int)  ->  ideal
// operation: <= (int, int)  ->  int
// operation: <= (bigint, bigint)  ->  int
// operation: <= (number, number)  ->  int
// operation: <= (string, string)  ->  int
// operation: <= (intvec, int)  ->  int
// operation: <= (intvec, intvec)  ->  int
// operation: <= (poly, poly)  ->  int
// operation: <= (vector, vector)  ->  int
// operation: < (int, int)  ->  int
// operation: < (bigint, bigint)  ->  int
// operation: < (number, number)  ->  int
// operation: < (intvec, int)  ->  int
// operation: < (intvec, intvec)  ->  int
// operation: < (string, string)  ->  int
// operation: < (poly, poly)  ->  int
// operation: < (vector, vector)  ->  int
// operation: >= (int, int)  ->  int
// operation: >= (bigint, bigint)  ->  int
// operation: >= (number, number)  ->  int
// operation: >= (string, string)  ->  int
// operation: >= (intvec, int)  ->  int
// operation: >= (intvec, intvec)  ->  int
// operation: >= (poly, poly)  ->  int
// operation: >= (vector, vector)  ->  int
// operation: > (int, int)  ->  int
// operation: > (bigint, bigint)  ->  int
// operation: > (number, number)  ->  int
// operation: > (string, string)  ->  int
// operation: > (intvec, int)  ->  int
// operation: > (intvec, intvec)  ->  int
// operation: > (poly, poly)  ->  int
// operation: > (vector, vector)  ->  int
// operation: and (int, int)  ->  int
// operation: or (int, int)  ->  int
// operation: == (int, int)  ->  int
// operation: == (bigint, bigint)  ->  int
// operation: == (number, number)  ->  int
// operation: == (string, string)  ->  int
// operation: == (poly, poly)  ->  int
// operation: == (vector, vector)  ->  int
// operation: == (intvec, int)  ->  int
// operation: == (intvec, intvec)  ->  int
// operation: == (intmat, intmat)  ->  int
// operation: == (matrix, matrix)  ->  int
// DUMMY // operation: == (ideal, ideal)  ->  $INVALID$
// DUMMY // operation: == (module, module)  ->  $INVALID$
// DUMMY // operation: == (ideal, module)  ->  $INVALID$
// DUMMY // operation: == (module, ideal)  ->  $INVALID$
// operation: <> (int, int)  ->  int
// operation: <> (bigint, bigint)  ->  int
// operation: <> (number, number)  ->  int
// operation: <> (string, string)  ->  int
// operation: <> (poly, poly)  ->  int
// operation: <> (vector, vector)  ->  int
// operation: <> (intvec, intvec)  ->  int
// operation: <> (intmat, intmat)  ->  int
// operation: <> (matrix, matrix)  ->  int
// DUMMY // operation: <> (ideal, ideal)  ->  $INVALID$
// DUMMY // operation: <> (module, module)  ->  $INVALID$
// DUMMY // operation: <> (ideal, module)  ->  $INVALID$
// DUMMY // operation: <> (module, ideal)  ->  $INVALID$
// operation: .. (int, int)  ->  intvec
// operation: [ (intvec, int)  ->  int
// operation: [ (intvec, intvec)  ->  int
// operation: [ (ideal, int)  ->  poly
// operation: [ (map, int)  ->  poly
// operation: [ (ideal, intvec)  ->  poly
// operation: [ (module, int)  ->  vector
// operation: [ (module, intvec)  ->  vector
// operation: [ (string, int)  ->  string
// operation: [ (string, intvec)  ->  string
// operation: [ (list, int)  ->  any_type
// operation: [ (list, intvec)  ->  any_type
// operation: [ (poly, int)  ->  poly
// operation: [ (poly, intvec)  ->  poly
// operation: [ (vector, int)  ->  poly
// operation: [ (vector, intvec)  ->  vector
// operation: ( (proc, def)  ->  any_type
// operation: ( (map, def)  ->  any_type
// operation: ( (any_type, int)  ->  any_type
// operation: ( (any_type, intvec)  ->  any_type
// operation: : (int, int)  ->  intvec
// operation: attrib (def, string)  ->  nothing
// DUMMY // operation: bareiss (def, def)  ->  $INVALID$
// operation: betti (list, int)  ->  intmat
// operation: betti (resolution, int)  ->  intmat
// operation: betti (ideal, int)  ->  intmat
// operation: betti (module, int)  ->  intmat
// operation: bracket (poly, poly)  ->  poly
// operation: chinrem (intvec, intvec)  ->  bigint
// operation: chinrem (list, intvec)  ->  any_type
// operation: chinrem (list, list)  ->  any_type
// operation: coef (poly, poly)  ->  matrix
// operation: coeffs (ideal, poly)  ->  matrix
// operation: coeffs (module, poly)  ->  matrix
// operation: coeffs (ideal, ideal)  ->  matrix
// operation: coeffs (module, module)  ->  matrix
// operation: contract (ideal, ideal)  ->  matrix
// operation: deg (poly, intvec)  ->  int
// operation: deg (vector, intvec)  ->  int
// operation: deg (matrix, intvec)  ->  int
// operation: delete (list, int)  ->  list
// operation: diff (poly, poly)  ->  poly
// operation: diff (vector, poly)  ->  vector
// operation: diff (ideal, poly)  ->  ideal
// operation: diff (ideal, ideal)  ->  matrix
// operation: diff (module, poly)  ->  module
// operation: diff (matrix, poly)  ->  matrix
// operation: dim (ideal, ideal)  ->  int
// operation: dim (module, ideal)  ->  int
// operation: division (ideal, ideal)  ->  list
// operation: division (module, module)  ->  list
// operation: eliminate (ideal, poly)  ->  ideal
// operation: eliminate (module, poly)  ->  module
// operation: eliminate (ideal, intvec)  ->  ideal
// operation: eliminate (module, intvec)  ->  module
// operation: exportto (package, identifier)  ->  nothing
// operation: extgcd (int, int)  ->  list
// operation: extgcd (poly, poly)  ->  list
// operation: factorize (poly, int)  ->  ideal
// operation: facstd (ideal, ideal)  ->  list
// operation: farey (bigint, bigint)  ->  number
// operation: farey (ideal, bigint)  ->  any_type
// operation: farey (module, bigint)  ->  any_type
// operation: farey (matrix, bigint)  ->  any_type
// operation: fetch (ring, any_type)  ->  any_type
// operation: fetch (qring, any_type)  ->  any_type
// operation: fglm (ring, def)  ->  ideal
// operation: fglm (qring, def)  ->  ideal
// operation: fglmquot (ideal, poly)  ->  ideal
// operation: find (string, string)  ->  int
// operation: frwalk (ring, def)  ->  ideal
// operation: gcd (int, int)  ->  int
// operation: gcd (number, number)  ->  number
// operation: gcd (bigint, bigint)  ->  bigint
// operation: gcd (poly, poly)  ->  poly
// operation: hilb (ideal, int)  ->  intvec
// operation: hilb (module, int)  ->  intvec
// operation: homog (ideal, intvec)  ->  int
// operation: homog (module, intvec)  ->  int
// operation: homog (poly, poly)  ->  poly
// operation: homog (vector, poly)  ->  vector
// operation: homog (ideal, poly)  ->  ideal
// operation: homog (module, poly)  ->  module
// operation: hres (ideal, int)  ->  resolution
// operation: ideal (def, def)  ->  ideal
// operation: imap (ring, any_type)  ->  any_type
// operation: imap (qring, any_type)  ->  any_type
// operation: importfrom (package, any_type)  ->  nothing
// operation: indepSet (ideal, int)  ->  list
// operation: insert (list, def)  ->  list
// operation: interpolation (list, intvec)  ->  ideal
// operation: intersect (ideal, ideal)  ->  ideal
// operation: intersect (module, module)  ->  module
// operation: janet (ideal, int)  ->  ideal
// operation: jet (poly, int)  ->  poly
// operation: jet (ideal, int)  ->  ideal
// operation: jet (vector, int)  ->  vector
// operation: jet (module, int)  ->  module
// operation: jet (matrix, int)  ->  matrix
// operation: kbase (ideal, int)  ->  ideal
// operation: kbase (module, int)  ->  module
// operation: kernel (ring, any_type)  ->  ideal
// operation: kernel (qring, any_type)  ->  ideal
// operation: killattrib (identifier, string)  ->  nothing
// operation: koszul (int, int)  ->  matrix
// operation: koszul (int, ideal)  ->  matrix
// operation: kres (ideal, int)  ->  resolution
// operation: lift (ideal, ideal)  ->  matrix
// operation: lift (module, module)  ->  matrix
// operation: liftstd (ideal, matrix)  ->  ideal
// operation: liftstd (module, matrix)  ->  module
// operation: list (def, def)  ->  list
// operation: load (string, string)  ->  nothing
// operation: lres (ideal, int)  ->  resolution
// operation: module (def, def)  ->  module
// operation: modulo (ideal, ideal)  ->  module
// operation: modulo (module, module)  ->  module
// operation: monitor (link, string)  ->  nothing
// operation: mpresmat (ideal, int)  ->  module
// operation: mres (ideal, int)  ->  resolution
// operation: mres (module, int)  ->  resolution
// operation: primefactors (bigint, int)  ->  list
// operation: primefactors (number, int)  ->  list
// operation: $INVALID$ (poly, poly)  ->  nothing
// operation: $INVALID$ (poly, matrix)  ->  nothing
// operation: $INVALID$ (matrix, poly)  ->  nothing
// operation: $INVALID$ (matrix, matrix)  ->  nothing
// operation: nc_algebra (poly, poly)  ->  ring
// operation: nc_algebra (poly, matrix)  ->  ring
// operation: nc_algebra (matrix, poly)  ->  ring
// operation: nc_algebra (matrix, matrix)  ->  ring
// operation: oppose (ring, def)  ->  any_type
// operation: oppose (qring, def)  ->  any_type
// operation: parstr (ring, int)  ->  string
// operation: parstr (qring, int)  ->  string
// operation: print (def, string)  ->  any_type
// operation: quotient (ideal, ideal)  ->  ideal
// operation: quotient (module, ideal)  ->  module
// operation: quotient (module, module)  ->  ideal
// operation: random (int, int)  ->  int
// operation: read (link, string)  ->  string
// operation: reduce (poly, ideal)  ->  poly
// operation: reduce (vector, ideal)  ->  vector
// operation: reduce (vector, module)  ->  vector
// operation: reduce (ideal, ideal)  ->  ideal
// operation: reduce (module, module)  ->  module
// operation: reduce (module, ideal)  ->  module
// operation: nres (ideal, int)  ->  resolution
// operation: nres (module, int)  ->  resolution
// operation: status (link, string)  ->  string
// operation: simplify (poly, int)  ->  poly
// operation: simplify (vector, int)  ->  vector
// operation: simplify (ideal, int)  ->  ideal
// operation: simplify (module, int)  ->  module
// operation: sres (ideal, int)  ->  resolution
// operation: sres (module, int)  ->  resolution
// operation: system (string, def)  ->  any_type
// operation: std (ideal, poly)  ->  ideal
// operation: std (module, vector)  ->  module
// operation: std (ideal, ideal)  ->  ideal
// operation: std (module, module)  ->  module
// operation: std (ideal, intvec)  ->  ideal
// operation: std (module, intvec)  ->  module
// operation: varstr (ring, int)  ->  string
// operation: varstr (qring, int)  ->  string
// operation: wedge (matrix, int)  ->  matrix
/*---------------------------------------------*/
// operation: [ (string, int, int)  ->  string
// operation: [ (intmat, int, int)  ->  int
// operation: [ (intmat, int, intvec)  ->  int
// operation: [ (intmat, intvec, int)  ->  int
// operation: [ (intmat, intvec, intvec)  ->  int
// operation: [ (matrix, int, int)  ->  poly
// operation: [ (matrix, int, intvec)  ->  poly
// operation: [ (matrix, intvec, int)  ->  poly
// operation: [ (matrix, intvec, intvec)  ->  poly
// operation: ( (proc, def, def)  ->  any_type
// operation: attrib (identifier, string, def)  ->  nothing
// operation: bareiss (module, int, int)  ->  list
// operation: coeffs (poly, poly, matrix)  ->  matrix
// operation: coeffs (vector, poly, matrix)  ->  matrix
// operation: coeffs (ideal, poly, matrix)  ->  matrix
// operation: coeffs (module, poly, matrix)  ->  matrix
// operation: coeffs (ideal, ideal, poly)  ->  matrix
// operation: coeffs (module, module, poly)  ->  matrix
// operation: eliminate (ideal, poly, intvec)  ->  ideal
// operation: eliminate (module, poly, intvec)  ->  module
// operation: find (string, string, int)  ->  int
// operation: frwalk (ring, def, int)  ->  ideal
// operation: hilb (ideal, int, intvec)  ->  intvec
// operation: hilb (module, int, intvec)  ->  intvec
// operation: homog (poly, poly, intvec)  ->  poly
// operation: homog (vector, poly, intvec)  ->  vector
// operation: homog (ideal, poly, intvec)  ->  ideal
// operation: homog (module, poly, intvec)  ->  module
// operation: ideal (def, def, def)  ->  ideal
// operation: insert (list, def, int)  ->  list
// operation: intmat (intmat, int, int)  ->  intmat
// operation: intvec (def, def, def)  ->  intvec
// operation: jet (poly, int, intvec)  ->  poly
// operation: jet (ideal, int, intvec)  ->  ideal
// operation: jet (vector, int, intvec)  ->  vector
// operation: jet (module, int, intvec)  ->  module
// operation: jet (poly, poly, int)  ->  poly
// operation: jet (vector, poly, int)  ->  vector
// operation: jet (ideal, matrix, int)  ->  ideal
// operation: jet (module, matrix, int)  ->  module
// DUMMY // operation: jet (poly, int, int)  ->  poly
// operation: koszul (int, int, ideal)  ->  matrix
// operation: liftstd (ideal, matrix, module)  ->  ideal
// operation: liftstd (module, matrix, module)  ->  module
// operation: list (def, def, def)  ->  list
// operation: matrix (ideal, int, int)  ->  matrix
// operation: matrix (module, int, int)  ->  matrix
// operation: matrix (matrix, int, int)  ->  matrix
// operation: module (def, def, def)  ->  module
// operation: lift (ideal, ideal, matrix)  ->  matrix
// operation: lift (module, module, matrix)  ->  matrix
// operation: preimage (ring, any_type, any_type)  ->  ideal
// operation: preimage (qring, any_type, any_type)  ->  ideal
// operation: random (int, int, int)  ->  intmat
// operation: reduce (poly, ideal, int)  ->  poly
// operation: reduce (vector, ideal, int)  ->  vector
// operation: reduce (vector, module, int)  ->  vector
// operation: reduce (ideal, ideal, int)  ->  ideal
// operation: reduce (module, module, int)  ->  module
// operation: reduce (module, ideal, int)  ->  module
// operation: reduce (poly, poly, ideal)  ->  poly
// operation: reduce (vector, poly, module)  ->  vector
// operation: reduce (ideal, ideal, matrix)  ->  ideal
// operation: reduce (module, module, matrix)  ->  module
// operation: resultant (poly, poly, poly)  ->  poly
// operation: ring (def, def, def)  ->  ring
// operation: status (link, string, string)  ->  int
// operation: std (ideal, intvec, intvec)  ->  ideal
// operation: std (module, intvec, intvec)  ->  module
// operation: subst (poly, poly, poly)  ->  poly
// operation: subst (poly, poly, poly)  ->  poly
// operation: subst (vector, poly, poly)  ->  vector
// operation: subst (ideal, poly, poly)  ->  ideal
// operation: subst (module, poly, poly)  ->  module
// operation: subst (matrix, poly, poly)  ->  matrix
// operation: subst (matrix, poly, int)  ->  matrix
// operation: subst (matrix, poly, number)  ->  matrix
// operation: system (string, def, def)  ->  nothing
// operation: laguerre (poly, int, int)  ->  list
// operation: vandermonde (ideal, ideal, int)  ->  poly
/*---------------------------------------------*/
// operation: ( (...)  ->  any_type ( number of arguments >0 )
// operation: breakpoint (...)  ->  nothing ( 0 arguments )
// operation: breakpoint (...)  ->  nothing ( number of arguments >0 )
// operation: coef (...)  ->  matrix ( 2 arguments )
// operation: coef (...)  ->  nothing ( 4 arguments )
// operation: division (...)  ->  any_type ( 2 arguments )
// operation: division (...)  ->  any_type ( 3 arguments )
// operation: division (...)  ->  any_type ( 4 arguments )
// operation: dbprint (...)  ->  nothing ( number of arguments >0 )
// operation: ideal (...)  ->  ideal ( 1 arguments )
// operation: ideal (...)  ->  ideal ( any number of arguments )
// operation: intersect (...)  ->  ideal ( 2 arguments )
// operation: intersect (...)  ->  ideal ( number of arguments >0 )
// operation: intvec (...)  ->  intvec ( 1 arguments )
// operation: intvec (...)  ->  intvec ( number of arguments >0 )
// operation: jet (...)  ->  poly ( 2 arguments )
// operation: jet (...)  ->  poly ( 3 arguments )
// operation: jet (...)  ->  poly ( 4 arguments )
// operation: list (...)  ->  list ( any number of arguments )
// operation: luinverse (...)  ->  list ( number of arguments >0 )
// operation: lusolve (...)  ->  list ( number of arguments >0 )
// operation: minor (...)  ->  nothing ( 1 arguments )
// operation: minor (...)  ->  ideal ( number of arguments >0 )
// operation: module (...)  ->  module ( 1 arguments )
// operation: module (...)  ->  module ( any number of arguments )
// operation: names (...)  ->  list ( 1 arguments )
// operation: names (...)  ->  list ( 0 arguments )
// operation: option (...)  ->  string ( any number of arguments )
// operation: reduce (...)  ->  ideal ( 2 arguments )
// operation: reduce (...)  ->  ideal ( 3 arguments )
// operation: reduce (...)  ->  ideal ( 4 arguments )
// operation: reduce (...)  ->  ideal ( 5 arguments )
// operation: reservedName (...)  ->  int ( 1 arguments )
// operation: reservedName (...)  ->  nothing ( 0 arguments )
// operation: string (...)  ->  string ( any number of arguments )
// operation: subst (...)  ->  nothing ( 3 arguments )
// operation: subst (...)  ->  nothing ( number of arguments >0 )
// operation: system (...)  ->  nothing ( number of arguments >0 )
// operation: test (...)  ->  nothing ( number of arguments >0 )
// operation: write (...)  ->  nothing ( number of arguments >0 )
// operation: status (...)  ->  string ( 2 arguments )
// operation: status (...)  ->  int ( 3 arguments )
// operation: status (...)  ->  int ( 4 arguments )
// operation: simplex (...)  ->  list ( 6 arguments )
// operation: uressolve (...)  ->  list ( 4 arguments )
// operation: std (...)  ->  ideal ( 1 arguments )
// operation: std (...)  ->  ideal ( 2 arguments )
// operation: std (...)  ->  ideal ( 3 arguments )
// operation: std (...)  ->  ideal ( 4 arguments )
/*---------------------------------------------*/
// assign: ideal =  ideal
// assign: ideal =  matrix
// assign: resolution =  resolution
// assign: int =  int
// assign: matrix =  matrix
// assign: map =  ideal
// assign: map =  map
// assign: module =  module
// assign: module =  poly
// assign: poly =  poly
// assign: poly =  matrix
// assign: qring =  ideal
// assign: ring =  ring
// assign: qring =  qring
// assign: string =  string
// assign: proc =  string
// assign: proc =  proc
// assign: vector =  vector
// assign: intvec =  intvec
// assign: intmat =  intmat
// assign: number =  number
// assign: bigint =  bigint
// assign: list =  resolution
// assign: list =  list
// assign: link =  string
// assign: link =  link
// assign: package =  package
/*---------------------------------------------*/
// convert intvec -> intmat
// convert poly -> ideal
// convert bigint -> ideal
// convert int -> ideal
// convert intmat -> matrix
// convert ideal -> matrix
// convert module -> matrix
// convert number -> matrix
// convert poly -> matrix
// convert vector -> matrix
// convert bigint -> matrix
// convert int -> matrix
// convert intvec -> matrix
// convert ideal -> module
// convert matrix -> module
// convert vector -> module
// convert bigint -> number
// convert int -> number
// convert number -> poly
// convert bigint -> poly
// convert int -> poly
// convert list -> resolution
// convert poly -> vector
// convert bigint -> vector
// convert int -> vector
// convert int -> bigint
// convert int -> intvec
// convert string -> link
// convert resolution -> list
/*---------------------------------------------*/
// token 61 : =
// token 62 : >
// token 60 : <
// token 43 : +
// token 42 : *
// token 47 : /
// token 91 : [
// token 46 : .
// token 94 : ^
// token 44 : ,
// token 37 : %
// token 40 : (
// token 59 : ;
// token 258 : ..
// token 259 : ==
// token 260 : >=
// token 261 : <=
// token 262 : --
// token 263 : not
// token 264 : <>
// token 265 : ++
// token 266 : ::
// token 268 : intmat
// token 269 : proc
// token 270 : ring
// token 272 : ideal
// token 273 : map
// token 274 : matrix
// token 275 : module
// token 276 : number
// token 277 : poly
// token 278 : resolution
// token 279 : vector
// token 280 : betti
// token 281 : chinrem
// token 282 : coeffs
// token 283 : coef
// token 284 : contract
// token 285 : degree
// token 286 : deg
// token 287 : diff
// token 288 : dim
// token 289 : division
// token 290 : eliminate
// token 291 : gen
// token 292 : farey
// token 293 : fetch
// token 294 : freemodule
// token 295 : keepring
// token 296 : hilb
// token 297 : homog
// token 298 : imap
// token 299 : indepSet
// token 300 : interred
// token 301 : intersect
// token 302 : jacob
// token 303 : jet
// token 304 : kbase
// token 305 : koszul
// token 306 : leadcoef
// token 307 : leadexp
// token 308 : lead
// token 309 : leadmonom
// token 310 : liftstd
// token 311 : lift
// token 312 : maxideal
// token 313 : minbase
// token 314 : minor
// token 315 : minres
// token 316 : modulo
// token 317 : monomial
// token 318 : mres
// token 319 : mult
// token 320 : ord
// token 321 : par
// token 322 : pardeg
// token 323 : preimage
// token 324 : quotient
// token 325 : qhweight
// token 326 : reduce
// token 327 : regularity
// token 328 : nres
// token 329 : simplify
// token 330 : sortvec
// token 331 : sres
// token 332 : std
// token 333 : subst
// token 334 : syz
// token 335 : var
// token 336 : vdim
// token 337 : wedge
// token 338 : weight
// token 340 : degBound
// token 341 : multBound
// token 342 : noether
// token 343 : minpoly
// token 344 : nothing
// token 356 : example
// token 357 : export
// token 359 : kill
// token 360 : LIB
// token 361 : listvar
// token 362 : setring
// token 363 : type
// token 370 : break
// token 371 : continue
// token 372 : else
// token 373 : eval
// token 374 : quote
// token 376 : forif
// token 379 : return
// token 380 : parameter
// token 384 : command
// token 385 : any_type
// token 386 : identifier
// token 397 : alias
// token 398 : attrib
// token 399 : bareiss
// token 400 : bigint
// token 401 : bracket
// token 402 : breakpoint
// token 403 : char
// token 404 : charstr
// token 405 : char_series
// token 406 : close
// token 407 : ncols
// token 408 : cleardenom
// token 409 : size
// token 410 : dbprint
// token 411 : def
// token 412 : defined
// token 413 : delete
// token 414 : det
// token 415 : dump
// token 416 : RETURN
// token 417 : envelope
// token 418 : ERROR
// token 419 : execute
// token 420 : exportto
// token 421 : extgcd
// token 422 : factorize
// token 423 : find
// token 424 : facstd
// token 425 : frwalk
// token 426 : fglm
// token 427 : fglmquot
// token 428 : finduni
// token 429 : gcd
// token 430 : getdump
// token 431 : highcorner
// token 432 : hres
// token 433 : impart
// token 434 : importfrom
// token 435 : insert
// token 436 : int
// token 437 : div
// token 438 : interpolation
// token 439 : mod
// token 440 : intvec
// token 441 : rvar
// token 442 : janet
// token 443 : kernel
// token 444 : killattrib
// token 445 : kres
// token 446 : laguerre
// token 447 : link
// token 448 : list
// token 449 : load
// token 450 : lres
// token 451 : ludecomp
// token 452 : luinverse
// token 453 : lusolve
// token 454 : memory
// token 455 : monitor
// token 456 : mpresmat
// token 457 : mstd
// token 458 : nameof
// token 459 : names
// token 461 : nc_algebra
// token 462 : convhull
// token 463 : npars
// token 464 : nvars
// token 465 : open
// token 466 : oppose
// token 467 : opposite
// token 468 : option
// token 469 : ordstr
// token 470 : package
// token 471 : parstr
// token 472 : primefactors
// token 474 : prime
// token 475 : print
// token 476 : prune
// token 477 : qring
// token 478 : random
// token 479 : read
// token 480 : repart
// token 481 : reservedName
// token 482 : resultant
// token 483 : ringlist
// token 484 : nrows
// token 485 : simplex
// token 486 : slimgb
// token 487 : sqrfree
// token 488 : status
// token 489 : string
// token 490 : system
// token 491 : test
// token 492 : transpose
// token 493 : trace
// token 494 : twostd
// token 495 : typeof
// token 496 : univariate
// token 498 : uressolve
// token 499 : vandermonde
// token 500 : variables
// token 501 : varstr
// token 502 : write
// token 503 : echo
// token 504 : pagelength
// token 505 : pagewidth
// token 506 : timer
// token 507 : rtimer
// token 508 : TRACE
// token 509 : voice
// token 510 : short
// token 511 : printlevel
/*--max. token: 512, gr: 382 --*/
/*---------------------------------------------*/
struct sValCmdTab dArithTab1[]=
{
 { 40,10 },
 { 45,2 },
 { 262,1 },
 { 265,0 },
 { 268,90 },
 { 270,173 },
 { 272,76 },
 { 273,119 },
 { 274,120 },
 { 275,127 },
 { 276,138 },
 { 277,155 },
 { 278,169 },
 { 279,209 },
 { 280,14 },
 { 285,51 },
 { 286,48 },
 { 288,57 },
 { 291,61 },
 { 294,66 },
 { 296,71 },
 { 297,74 },
 { 299,83 },
 { 300,88 },
 { 302,96 },
 { 304,100 },
 { 306,110 },
 { 307,112 },
 { 308,106 },
 { 309,114 },
 { 312,121 },
 { 313,123 },
 { 315,125 },
 { 317,129 },
 { 319,130 },
 { 320,146 },
 { 321,150 },
 { 322,151 },
 { 323,157 },
 { 325,162 },
 { 327,166 },
 { 330,182 },
 { 332,185 },
 { 334,189 },
 { 335,212 },
 { 336,210 },
 { 338,216 },
 { 360,116 },
 { 398,12 },
 { 399,13 },
 { 400,18 },
 { 403,21 },
 { 404,24 },
 { 405,23 },
 { 406,26 },
 { 407,27 },
 { 408,32 },
 { 409,34 },
 { 411,46 },
 { 412,53 },
 { 414,54 },
 { 415,60 },
 { 417,191 },
 { 418,63 },
 { 419,62 },
 { 422,64 },
 { 424,67 },
 { 428,65 },
 { 430,68 },
 { 431,69 },
 { 433,82 },
 { 436,84 },
 { 440,91 },
 { 441,93 },
 { 442,99 },
 { 444,105 },
 { 447,117 },
 { 448,118 },
 { 449,218 },
 { 451,102 },
 { 454,122 },
 { 455,128 },
 { 457,132 },
 { 458,134 },
 { 459,135 },
 { 462,219 },
 { 463,141 },
 { 464,143 },
 { 465,145 },
 { 467,193 },
 { 469,148 },
 { 471,152 },
 { 472,103 },
 { 474,158 },
 { 475,159 },
 { 476,161 },
 { 477,164 },
 { 479,165 },
 { 480,167 },
 { 481,168 },
 { 483,171 },
 { 484,175 },
 { 486,180 },
 { 487,184 },
 { 489,187 },
 { 490,188 },
 { 492,200 },
 { 493,196 },
 { 494,195 },
 { 495,204 },
 { 496,205 },
 { 500,206 },
 { 501,213 },
 { 10000,0 }
};
#define JJTAB1LEN 113
struct sValCmdTab dArithTab2[]=
{
 { 37,79 },
 { 38,126 },
 { 40,171 },
 { 42,36 },
 { 43,1 },
 { 45,23 },
 { 47,67 },
 { 58,175 },
 { 60,102 },
 { 62,118 },
 { 91,156 },
 { 94,89 },
 { 124,127 },
 { 258,155 },
 { 259,128 },
 { 260,110 },
 { 261,94 },
 { 264,142 },
 { 266,0 },
 { 272,239 },
 { 275,269 },
 { 280,178 },
 { 281,183 },
 { 282,187 },
 { 283,186 },
 { 284,191 },
 { 286,192 },
 { 287,196 },
 { 288,202 },
 { 289,204 },
 { 290,206 },
 { 292,215 },
 { 293,219 },
 { 296,230 },
 { 297,232 },
 { 298,240 },
 { 299,243 },
 { 301,246 },
 { 303,249 },
 { 304,254 },
 { 305,259 },
 { 310,264 },
 { 311,262 },
 { 316,270 },
 { 318,274 },
 { 324,291 },
 { 326,296 },
 { 328,302 },
 { 329,305 },
 { 331,309 },
 { 332,312 },
 { 337,320 },
 { 398,176 },
 { 399,177 },
 { 401,182 },
 { 413,195 },
 { 420,210 },
 { 421,211 },
 { 422,213 },
 { 423,224 },
 { 424,214 },
 { 425,225 },
 { 426,221 },
 { 427,223 },
 { 429,226 },
 { 432,238 },
 { 434,242 },
 { 435,244 },
 { 437,75 },
 { 438,245 },
 { 439,84 },
 { 442,248 },
 { 443,256 },
 { 444,258 },
 { 445,261 },
 { 448,266 },
 { 449,267 },
 { 450,268 },
 { 455,272 },
 { 456,273 },
 { 460,278 },
 { 461,282 },
 { 466,286 },
 { 471,288 },
 { 472,276 },
 { 475,290 },
 { 478,294 },
 { 479,295 },
 { 488,304 },
 { 490,311 },
 { 501,318 },
 { 10000,0 }
};
#define JJTAB2LEN 91
/****************************************
*  Computer Algebra System SINGULAR     *
****************************************/

// identifier table for Singular
//
#ifdef MODULE_GENERATOR
#define omAlloc0(A) malloc(A)
#endif
void iiInitCmdName()
{
  sArithBase.nCmdUsed      = 0;
  sArithBase.nCmdAllocated = 220;
  sArithBase.sCmds = (cmdnames*)omAlloc0(sArithBase.nCmdAllocated*sizeof(cmdnames));

  // name-string                   alias  tokval toktype index
  iiArithAddCmd("$INVALID$",           0,  -1, 0, 0);
  iiArithAddCmd("ERROR",               0, 418, CMD_1, 1);
  iiArithAddCmd("GCD",                 2, 429, CMD_2, 2);
  iiArithAddCmd("IN",                  1, 308, CMD_1, 3);
  iiArithAddCmd("LIB",                 0, 360, SYSVAR, 4);
  iiArithAddCmd("NF",                  1, 326, CMD_M, 5);
  iiArithAddCmd("RETURN",              0, 416, 379, 6);
  iiArithAddCmd("TRACE",               0, 508, SYSVAR, 7);
  iiArithAddCmd("alias",               0, 397, 380, 8);
  iiArithAddCmd("and",                 0,  38, '&', 9);
  iiArithAddCmd("attrib",              0, 398, CMD_123, 10);
  iiArithAddCmd("bareiss",             0, 399, CMD_123, 11);
  iiArithAddCmd("betti",               0, 280, CMD_12, 12);
  iiArithAddCmd("bigint",              0, 400, ROOT_DECL, 13);
  iiArithAddCmd("bracket",             0, 401, CMD_2, 14);
  iiArithAddCmd("break",               0, 370, 370, 15);
  iiArithAddCmd("breakpoint",          0, 402, CMD_M, 16);
  iiArithAddCmd("char",                0, 403, CMD_1, 17);
  iiArithAddCmd("char_series",         0, 405, CMD_1, 18);
  iiArithAddCmd("charstr",             0, 404, CMD_1, 19);
  iiArithAddCmd("chinrem",             0, 281, CMD_2, 20);
  iiArithAddCmd("cleardenom",          0, 408, CMD_1, 21);
  iiArithAddCmd("close",               0, 406, CMD_1, 22);
  iiArithAddCmd("coef",                0, 283, CMD_M, 23);
  iiArithAddCmd("coeffs",              0, 282, CMD_23, 24);
  iiArithAddCmd("continue",            0, 371, 371, 25);
  iiArithAddCmd("contract",            0, 284, CMD_2, 26);
  iiArithAddCmd("convhull",            0, 462, CMD_1, 27);
  iiArithAddCmd("dbprint",             0, 410, CMD_M, 28);
  iiArithAddCmd("def",                 0, 411, ROOT_DECL, 29);
  iiArithAddCmd("defined",             0, 412, CMD_1, 30);
  iiArithAddCmd("deg",                 0, 286, CMD_12, 31);
  iiArithAddCmd("degBound",            0, 340, SYSVAR, 32);
  iiArithAddCmd("degree",              0, 285, CMD_1, 33);
  iiArithAddCmd("delete",              0, 413, CMD_2, 34);
  iiArithAddCmd("det",                 0, 414, CMD_1, 35);
  iiArithAddCmd("diff",                0, 287, CMD_2, 36);
  iiArithAddCmd("dim",                 0, 288, CMD_1, 37);
  iiArithAddCmd("div",                 0, 437, '/', 38);
  iiArithAddCmd("division",            0, 289, CMD_M, 39);
  iiArithAddCmd("dump",                0, 415, CMD_1, 40);
  iiArithAddCmd("echo",                0, 503, SYSVAR, 41);
  iiArithAddCmd("eliminate",           0, 290, CMD_23, 42);
  iiArithAddCmd("else",                0, 372, 372, 43);
  iiArithAddCmd("envelope",            0, 417, CMD_1, 44);
  iiArithAddCmd("eval",                0, 373, 373, 45);
  iiArithAddCmd("example",             0, 356, 356, 46);
  iiArithAddCmd("execute",             0, 419, CMD_1, 47);
  iiArithAddCmd("export",              0, 357, 357, 48);
  iiArithAddCmd("exportto",            0, 420, CMD_2, 49);
  iiArithAddCmd("extgcd",              0, 421, CMD_2, 50);
  iiArithAddCmd("facstd",              0, 424, CMD_12, 51);
  iiArithAddCmd("factorize",           0, 422, CMD_12, 52);
  iiArithAddCmd("farey",               0, 292, CMD_2, 53);
  iiArithAddCmd("fetch",               0, 293, CMD_2, 54);
  iiArithAddCmd("fglm",                0, 426, CMD_2, 55);
  iiArithAddCmd("fglmquot",            0, 427, CMD_2, 56);
  iiArithAddCmd("find",                0, 423, CMD_23, 57);
  iiArithAddCmd("finduni",             0, 428, CMD_1, 58);
  iiArithAddCmd("forif",               0, 376, 376, 59);
  iiArithAddCmd("freemodule",          0, 294, CMD_1, 60);
  iiArithAddCmd("frwalk",              0, 425, CMD_23, 61);
  iiArithAddCmd("gcd",                 0, 429, CMD_2, 62);
  iiArithAddCmd("gen",                 0, 291, CMD_1, 63);
  iiArithAddCmd("getdump",             0, 430, CMD_1, 64);
  iiArithAddCmd("highcorner",          0, 431, CMD_1, 65);
  iiArithAddCmd("hilb",                0, 296, CMD_123, 66);
  iiArithAddCmd("homog",               0, 297, CMD_123, 67);
  iiArithAddCmd("hres",                0, 432, CMD_2, 68);
  iiArithAddCmd("ideal",               0, 272, 272, 69);
  iiArithAddCmd("if",                  0, 376, 376, 70);
  iiArithAddCmd("imap",                0, 298, CMD_2, 71);
  iiArithAddCmd("impart",              0, 433, CMD_1, 72);
  iiArithAddCmd("importfrom",          0, 434, CMD_2, 73);
  iiArithAddCmd("indepSet",            0, 299, CMD_12, 74);
  iiArithAddCmd("insert",              0, 435, CMD_23, 75);
  iiArithAddCmd("int",                 0, 436, ROOT_DECL, 76);
  iiArithAddCmd("interpolation",       0, 438, CMD_2, 77);
  iiArithAddCmd("interred",            0, 300, CMD_1, 78);
  iiArithAddCmd("intersect",           0, 301, CMD_M, 79);
  iiArithAddCmd("intmat",              0, 268, 268, 80);
  iiArithAddCmd("intvec",              0, 440, ROOT_DECL_LIST, 81);
  iiArithAddCmd("jacob",               0, 302, CMD_1, 82);
  iiArithAddCmd("janet",               0, 442, CMD_12, 83);
  iiArithAddCmd("jet",                 0, 303, CMD_M, 84);
  iiArithAddCmd("kbase",               0, 304, CMD_12, 85);
  iiArithAddCmd("keepring",            0, 295, 295, 86);
  iiArithAddCmd("kernel",              0, 443, CMD_2, 87);
  iiArithAddCmd("kill",                0, 359, 359, 88);
  iiArithAddCmd("killattrib",          0, 444, CMD_12, 89);
  iiArithAddCmd("koszul",              0, 305, CMD_23, 90);
  iiArithAddCmd("kres",                0, 445, CMD_2, 91);
  iiArithAddCmd("laguerre",            0, 446, CMD_3, 92);
  iiArithAddCmd("lead",                0, 308, CMD_1, 93);
  iiArithAddCmd("leadcoef",            0, 306, CMD_1, 94);
  iiArithAddCmd("leadexp",             0, 307, CMD_1, 95);
  iiArithAddCmd("leadmonom",           0, 309, CMD_1, 96);
  iiArithAddCmd("lift",                0, 311, CMD_23, 97);
  iiArithAddCmd("liftstd",             0, 310, CMD_23, 98);
  iiArithAddCmd("link",                0, 447, ROOT_DECL, 99);
  iiArithAddCmd("list",                0, 448, ROOT_DECL_LIST, 100);
  iiArithAddCmd("listvar",             0, 361, 361, 101);
  iiArithAddCmd("load",                0, 449, CMD_12, 102);
  iiArithAddCmd("lres",                0, 450, CMD_2, 103);
  iiArithAddCmd("ludecomp",            0, 451, CMD_1, 104);
  iiArithAddCmd("luinverse",           0, 452, CMD_M, 105);
  iiArithAddCmd("lusolve",             0, 453, CMD_M, 106);
  iiArithAddCmd("map",                 0, 273, RING_DECL, 107);
  iiArithAddCmd("matrix",              0, 274, 274, 108);
  iiArithAddCmd("maxideal",            0, 312, CMD_1, 109);
  iiArithAddCmd("memory",              0, 454, CMD_1, 110);
  iiArithAddCmd("minbase",             0, 313, CMD_1, 111);
  iiArithAddCmd("minor",               0, 314, CMD_M, 112);
  iiArithAddCmd("minpoly",             0, 343, SYSVAR, 113);
  iiArithAddCmd("minres",              0, 315, CMD_1, 114);
  iiArithAddCmd("mod",                 0, 439, '/', 115);
  iiArithAddCmd("module",              0, 275, 275, 116);
  iiArithAddCmd("modulo",              0, 316, CMD_2, 117);
  iiArithAddCmd("monitor",             0, 455, CMD_12, 118);
  iiArithAddCmd("monomial",            0, 317, CMD_1, 119);
  iiArithAddCmd("mpresmat",            0, 456, CMD_2, 120);
  iiArithAddCmd("mres",                0, 318, CMD_2, 121);
  iiArithAddCmd("mstd",                0, 457, CMD_1, 122);
  iiArithAddCmd("mult",                0, 319, CMD_1, 123);
  iiArithAddCmd("multBound",           0, 341, SYSVAR, 124);
  iiArithAddCmd("multiplicity",        1, 319, CMD_1, 125);
  iiArithAddCmd("nameof",              0, 458, CMD_1, 126);
  iiArithAddCmd("names",               0, 459, CMD_M, 127);
  iiArithAddCmd("nc_algebra",          0, 461, CMD_2, 128);
  iiArithAddCmd("ncalgebra",           2, 460, CMD_2, 129);
  iiArithAddCmd("ncols",               0, 407, CMD_1, 130);
  iiArithAddCmd("noether",             0, 342, SYSVAR, 131);
  iiArithAddCmd("not",                 0, 263, 263, 132);
  iiArithAddCmd("npars",               0, 463, CMD_1, 133);
  iiArithAddCmd("nres",                0, 328, CMD_2, 134);
  iiArithAddCmd("nrows",               0, 484, CMD_1, 135);
  iiArithAddCmd("number",              0, 276, RING_DECL, 136);
  iiArithAddCmd("nvars",               0, 464, CMD_1, 137);
  iiArithAddCmd("open",                0, 465, CMD_1, 138);
  iiArithAddCmd("oppose",              0, 466, CMD_2, 139);
  iiArithAddCmd("opposite",            0, 467, CMD_1, 140);
  iiArithAddCmd("option",              0, 468, CMD_M, 141);
  iiArithAddCmd("or",                  0, 124, '&', 142);
  iiArithAddCmd("ord",                 0, 320, CMD_1, 143);
  iiArithAddCmd("ordstr",              0, 469, CMD_1, 144);
  iiArithAddCmd("package",             0, 470, ROOT_DECL, 145);
  iiArithAddCmd("pagelength",          0, 504, SYSVAR, 146);
  iiArithAddCmd("pagewidth",           0, 505, SYSVAR, 147);
  iiArithAddCmd("par",                 0, 321, CMD_1, 148);
  iiArithAddCmd("parameter",           0, 380, 380, 149);
  iiArithAddCmd("pardeg",              0, 322, CMD_1, 150);
  iiArithAddCmd("parstr",              0, 471, CMD_12, 151);
  iiArithAddCmd("poly",                0, 277, RING_DECL, 152);
  iiArithAddCmd("preimage",            0, 323, 349, 153);
  iiArithAddCmd("prime",               0, 474, CMD_1, 154);
  iiArithAddCmd("primefactors",        0, 472, CMD_12, 155);
  iiArithAddCmd("print",               0, 475, CMD_12, 156);
  iiArithAddCmd("printlevel",          0, 511, SYSVAR, 157);
  iiArithAddCmd("proc",                0, 269, 269, 158);
  iiArithAddCmd("prune",               0, 476, CMD_1, 159);
  iiArithAddCmd("qhweight",            0, 325, CMD_1, 160);
  iiArithAddCmd("qring",               0, 477, ROOT_DECL, 161);
  iiArithAddCmd("quote",               0, 374, 374, 162);
  iiArithAddCmd("quotient",            0, 324, CMD_2, 163);
  iiArithAddCmd("random",              0, 478, CMD_23, 164);
  iiArithAddCmd("read",                0, 479, CMD_12, 165);
  iiArithAddCmd("reduce",              0, 326, CMD_M, 166);
  iiArithAddCmd("regularity",          0, 327, CMD_1, 167);
  iiArithAddCmd("repart",              0, 480, CMD_1, 168);
  iiArithAddCmd("reservedName",        0, 481, CMD_M, 169);
  iiArithAddCmd("resolution",          0, 278, RING_DECL, 170);
  iiArithAddCmd("resultant",           0, 482, CMD_3, 171);
  iiArithAddCmd("return",              0, 379, 379, 172);
  iiArithAddCmd("ring",                0, 270, 270, 173);
  iiArithAddCmd("ringlist",            0, 483, CMD_1, 174);
#ifdef HAVE_RTIMER
  iiArithAddCmd("rtimer",              0, 507, SYSVAR, 175);
#endif
  iiArithAddCmd("rvar",                0, 441, CMD_1, 176);
  iiArithAddCmd("setring",             0, 362, 362, 177);
  iiArithAddCmd("short",               0, 510, SYSVAR, 178);
  iiArithAddCmd("simplex",             0, 485, CMD_M, 179);
  iiArithAddCmd("simplify",            0, 329, CMD_2, 180);
  iiArithAddCmd("size",                0, 409, CMD_1, 181);
  iiArithAddCmd("slimgb",              0, 486, CMD_1, 182);
  iiArithAddCmd("sortvec",             0, 330, CMD_1, 183);
  iiArithAddCmd("sqrfree",             0, 487, CMD_1, 184);
  iiArithAddCmd("sres",                0, 331, CMD_2, 185);
  iiArithAddCmd("status",              0, 488, CMD_M, 186);
  iiArithAddCmd("std",                 0, 332, CMD_M, 187);
  iiArithAddCmd("string",              0, 489, ROOT_DECL_LIST, 188);
  iiArithAddCmd("subst",               0, 333, CMD_M, 189);
  iiArithAddCmd("system",              0, 490, CMD_M, 190);
  iiArithAddCmd("syz",                 0, 334, CMD_1, 191);
  iiArithAddCmd("test",                0, 491, CMD_M, 192);
  iiArithAddCmd("timer",               0, 506, SYSVAR, 193);
  iiArithAddCmd("trace",               0, 493, CMD_1, 194);
  iiArithAddCmd("transpose",           0, 492, CMD_1, 195);
  iiArithAddCmd("twostd",              0, 494, CMD_1, 196);
  iiArithAddCmd("type",                0, 363, 363, 197);
  iiArithAddCmd("typeof",              0, 495, CMD_1, 198);
  iiArithAddCmd("univariate",          0, 496, CMD_1, 199);
  iiArithAddCmd("uressolve",           0, 498, CMD_M, 200);
  iiArithAddCmd("vandermonde",         0, 499, CMD_3, 201);
  iiArithAddCmd("var",                 0, 335, CMD_1, 202);
  iiArithAddCmd("variables",           0, 500, CMD_1, 203);
  iiArithAddCmd("varstr",              0, 501, CMD_12, 204);
  iiArithAddCmd("vdim",                0, 336, CMD_1, 205);
  iiArithAddCmd("vector",              0, 279, RING_DECL, 206);
  iiArithAddCmd("verbose",             2, 468, CMD_M, 207);
  iiArithAddCmd("voice",               0, 509, SYSVAR, 208);
  iiArithAddCmd("wedge",               0, 337, CMD_2, 209);
  iiArithAddCmd("weight",              0, 338, CMD_1, 210);
  iiArithAddCmd("whileif",             0, 376, 376, 211);
  iiArithAddCmd("write",               0, 502, CMD_M, 212);
  iiArithAddCmd("exit",                0,  -1, 0, 213);
  iiArithAddCmd("for",                 0,  -1, 0, 214);
  iiArithAddCmd("help",                0,  -1, 0, 215);
  iiArithAddCmd("newline",             0,  -1, 0, 216);
  iiArithAddCmd("pause",               2,  -1, 0, 217);
  iiArithAddCmd("quit",                0,  -1, 0, 218);
  iiArithAddCmd("while",               0,  -1, 0, 219);
/* end of list marker */
#ifdef HAVE_RTIMER
  sArithBase.nLastIdentifier = 212;
#else /* HAVE_RTIMER */
  sArithBase.nLastIdentifier = 211;
#endif /* HAVE_RTIMER */
}
#ifdef HAVE_RTIMER
#define LAST_IDENTIFIER 212
#else
#define LAST_IDENTIFIER 211
#endif
